==> knetworkmanager8-trinity-3.5.13.2.tar.xz: knetworkmanager8-trinity-3.5.13.2/knetworkmanager-0.8/src/knetworkmanager-menu_subhead.cpp <==
/***************************************************************************
 *
 * knetworkmanager-tray.cpp - A NetworkManager frontend for KDE
 *
 * Copyright (C) 2005, 2006 Novell, Inc.
 *
 * Author: Timo Hoenig        <thoenig@suse.de>, <thoenig@nouse.net>
 *         Will Stephenson    <wstephenson@suse.de>, <wstephenson@kde.org>
 *         Valentine Sinitsyn <e_val@inbox.ru>
 *         Helmut Schaa       <hschaa@suse.de>, <helmut.schaa@gmx.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 **************************************************************************/

class WirelessDialog;

#include <tqevent.h>
#include <tqvbox.h>
#include <tqlayout.h>
#include <tqpushbutton.h>
#include <tqpixmap.h>
#include <tqpixmapcache.h>
#include <tqpainter.h>
#include <tqstyle.h>
#include <dcopclient.h>
#include <kdebug.h>
#include <kdialogbase.h>
#include <knotifyclient.h>
#include <knotifydialog.h>
#include <klocale.h>
#include <kstdguiitem.h>
#include <khelpmenu.h>
#include <kprocess.h>
#include <kiconloader.h>
#include <kconfig.h>
#include <kmessagebox.h>

#include "knetworkmanager-menu_subhead.h"

Subhead::Subhead (TQWidget* parent, const char* name, const TQString & caption, const TQPixmap icon)
       : TQWidget (parent, name)
{
	TQBoxLayout* l        = new TQHBoxLayout (this);
	TQLabel* lbl_icon     = new TQLabel (NULL, this);
	TQLabel* lbl_caption  = new TQLabel (caption, this);
	TQSpacerItem* sp_item = new TQSpacerItem (20, 10);
	TQFont font;
	font.setBold(true);
	lbl_caption->setFont(font);

	lbl_icon->setPixmap (icon);

	l->addWidget (lbl_icon);
	l->addWidget (lbl_caption);
	l->addItem (sp_item);
	l->activate ();
}

Subhead::~Subhead()
{

}

==> knetworkmanager8-trinity_14.0.6.orig.tar.xz: knetworkmanager8-trinity-14.0.6/knetworkmanager-0.8/src/knetworkmanager-menu_subhead.cpp <==
/***************************************************************************
 *
 * knetworkmanager-tray.cpp - A NetworkManager frontend for KDE
 *
 * Copyright (C) 2005, 2006 Novell, Inc.
 *
 * Author: Timo Hoenig        <thoenig@suse.de>, <thoenig@nouse.net>
 *         Will Stephenson    <wstephenson@suse.de>, <wstephenson@kde.org>
 *         Valentine Sinitsyn <e_val@inbox.ru>
 *         Helmut Schaa       <hschaa@suse.de>, <helmut.schaa@gmx.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 **************************************************************************/

class WirelessDialog;

#include <tqevent.h>
#include <tqvbox.h>
#include <tqlayout.h>
#include <tqpushbutton.h>
#include <tqpixmap.h>
#include <tqpixmapcache.h>
#include <tqpainter.h>
#include <tqstyle.h>
#include <dcopclient.h>
#include <kdebug.h>
#include <kdialogbase.h>
#include <knotifyclient.h>
#include <knotifydialog.h>
#include <tdelocale.h>
#include <kstdguiitem.h>
#include <khelpmenu.h>
#include <kprocess.h>
#include <kiconloader.h>
#include <tdeconfig.h>
#include <tdemessagebox.h>

#include "knetworkmanager-menu_subhead.h"

Subhead::Subhead (TQWidget* parent, const char* name, const TQString & caption, const TQPixmap icon)
       : TQWidget (parent, name)
{
	TQBoxLayout* l        = new TQHBoxLayout (this);
	TQLabel* lbl_icon     = new TQLabel (NULL, this);
	TQLabel* lbl_caption  = new TQLabel (caption, this);
	TQSpacerItem* sp_item = new TQSpacerItem (20, 10);
	TQFont font;
	font.setBold(true);
	lbl_caption->setFont(font);

	lbl_icon->setPixmap (icon);

	l->addWidget (lbl_icon);
	l->addWidget (lbl_caption);
	l->addItem (sp_item);
	l->activate ();
}

Subhead::~Subhead()
{

}
